==> vdcpy-0.0.7.tar.gz: vdcpy-0.0.7/tests/work_tests/add_work_test.py <==
import unittest

import vdcpy.work as vdc_work
import vdcpy.project as vdc_project
import vdcpy.user as vdc_user
import tests.utils.project_util as project_util
import tests.utils.user_util as user_util
import tests.utils.work_util as work_util


class AddWorkTest(unittest.TestCase):

    def setUp(self):
        user_util.delete_unittest_users()
        user_util.add_unittest_user()
        project_util.add_unittest_project()

    def test_successful_add_work(self):
        # Get unittest user id
        user_list = vdc_user.get_users(name='unittest_user')
        user_id = user_list[0]['id']
        # Get unittest project id
        project_list = vdc_project.get_projects(title='unittest_project')
        project_id = project_list[0]['id']

        work_info = {
            'title': 'unittest_work',
            'abstract': 'unittest_abstract',
            'genre': 'DataSet',
            'visibility': 'open',
            'project': project_id,
            'created_by': user_id
        }
        new_work = vdc_work.add_work(work_info)
        self.assertEqual(type(new_work), dict)

    def test_fail_add_work_no_title(self):
        # Get unittest user id
        user_list = vdc_user.get_users(name='unittest_user')
        user_id = user_list[0]['id']
        # Get unittest project id
        project_list = vdc_project.get_projects(title='unittest_project')
        project_id = project_list[0]['id']

        work_info = {
            # 'title': 'unittest_work',
            'abstract': 'unittest_abstract',
            'genre': 'DataSet',
            'visibility': 'open',
            'project': project_id,
            'created_by': user_id
        }
        try:
            new_work = vdc_work.add_work(work_info)
            self.assertEqual(new_work, 'You are not here')
        except Exception as e:
            self.assertEqual(
                str(e),
                "Error adding work: 400 - {'message': 'Title is required.'}")

    def test_fail_add_work_no_abstract(self):
        # Get unittest user id
        user_list = vdc_user.get_users(name='unittest_user')
        user_id = user_list[0]['id']
        # Get unittest project id
        project_list = vdc_project.get_projects(title='unittest_project')
        project_id = project_list[0]['id']

        work_info = {
            'title': 'unittest_work',
            # 'abstract': 'unittest_abstract',
            'genre': 'DataSet',
            'visibility': 'open',
            'project': project_id,
            'created_by': user_id
        }
        try:
            new_work = vdc_work.add_work(work_info)
            self.assertEqual(new_work, 'You are not here')
        except Exception as e:
            self.assertEqual(
                str(e),
                "Error adding work: 400 - {'message': 'Abstract is required.'}")
    
    def test_fail_add_work_no_genre(self):
        # Get unittest user id
        user_list = vdc_user.get_users(name='unittest_user')
        user_id = user_list[0]['id']
        # Get unittest project id
        project_list = vdc_project.get_projects(title='unittest_project')
        project_id = project_list[0]['id']

        work_info = {
            'title': 'unittest_work',
            'abstract': 'unittest_abstract',
            # 'genre': 'DataSet',
            'visibility': 'open',
            'project': project_id,
            'created_by': user_id
        }
        try:
            new_work = vdc_work.add_work(work_info)
            self.assertEqual(new_work, 'You are not here')
        except Exception as e:
            self.assertEqual(
                str(e),
                "Error adding work: 400 - {'message': 'Genre is required.'}")

    def test_fail_add_work_no_visibility(self):
        # Get unittest user id
        user_list = vdc_user.get_users(name='unittest_user')
        user_id = user_list[0]['id']
        # Get unittest project id
        project_list = vdc_project.get_projects(title='unittest_project')
        project_id = project_list[0]['id']

        work_info = {
            'title': 'unittest_work',
            'abstract': 'unittest_abstract',
            'genre': 'DataSet',
            # 'visibility': 'open',
            'project': project_id,
            'created_by': user_id
        }
        try:
            new_work = vdc_work.add_work(work_info)
            self.assertEqual(new_work, 'You are not here')
        except Exception as e:
            self.assertEqual(
                str(e),
                "Error adding work: 400 - {'message': 'Visibility is required.'}")
    
    def test_fail_add_work_no_project(self):
        # Get unittest user id
        user_list = vdc_user.get_users(name='unittest_user')
        user_id = user_list[0]['id']
        # Get unittest project id
        project_list = vdc_project.get_projects(title='unittest_project')
        project_id = project_list[0]['id']

        work_info = {
            'title': 'unittest_work',
            'abstract': 'unittest_abstract',
            'genre': 'DataSet',
            'visibility': 'open',
            # 'project': project_id,
            'created_by': user_id
        }
        try:
            new_work = vdc_work.add_work(work_info)
            self.assertEqual(new_work, 'You are not here')
        except Exception as e:
            self.assertEqual(
                str(e),
                "Error adding work: 400 - {'message': 'Project is required.'}")
    
    def test_fail_add_work_no_created_by(self):
        # Get unittest user id
        user_list = vdc_user.get_users(name='unittest_user')
        user_id = user_list[0]['id']
        # Get unittest project id
        project_list = vdc_project.get_projects(title='unittest_project')
        project_id = project_list[0]['id']

        work_info = {
            'title': 'unittest_work',
            'abstract': 'unittest_abstract',
            'genre': 'DataSet',
            'visibility': 'open',
            'project': project_id,
            # 'created_by': user_id
        }
        try:
            new_work = vdc_work.add_work(work_info)
            self.assertEqual(new_work, 'You are not here')
        except Exception as e:
            self.assertEqual(
                str(e),
                "Error adding work: 400 - {'message': 'created_by is required.'}")

    def tearDown(self):
        work_util.delete_unittest_works()
        project_util.delete_unittest_project()
        user_util.delete_unittest_users()

==> vdcpy-0.0.11.tar.gz: vdcpy-0.0.11/tests/work_tests/add_work_test.py <==
import unittest

import vdcpy.work as vdc_work
import vdcpy.project as vdc_project
import vdcpy.user as vdc_user
import tests.utils.project_util as project_util
import tests.utils.user_util as user_util
import tests.utils.work_util as work_util


class AddWorkTest(unittest.TestCase):

    def setUp(self):
        user_util.delete_unittest_users()
        user_util.add_unittest_user()
        project_util.add_unittest_project()

    def test_successful_add_work(self):
        # Get unittest user id
        user_list = vdc_user.get_users(name='unittest_user')
        user_id = user_list[0]['id']
        # Get unittest project id
        project_list = vdc_project.get_projects(title='unittest_project')
        project_id = project_list[0]['id']

        work_info = {
            'title': 'unittest_work',
            'abstract': 'unittest_abstract',
            'genre': 'DataSet',
            'visibility': 'open',
            'project': project_id,
            'created_by': user_id
        }
        new_work = vdc_work.add_work(work_info, auth_token='t3st')
        self.assertEqual(type(new_work), dict)

    def test_fail_add_work_no_title(self):
        # Get unittest user id
        user_list = vdc_user.get_users(name='unittest_user')
        user_id = user_list[0]['id']
        # Get unittest project id
        project_list = vdc_project.get_projects(title='unittest_project')
        project_id = project_list[0]['id']

        work_info = {
            # 'title': 'unittest_work',
            'abstract': 'unittest_abstract',
            'genre': 'DataSet',
            'visibility': 'open',
            'project': project_id,
            'created_by': user_id
        }
        try:
            new_work = vdc_work.add_work(work_info, auth_token='t3st')
            self.assertEqual(new_work, 'You are not here')
        except Exception as e:
            self.assertEqual(
                str(e),
                "Error adding work: 400 - {'message': 'Title is required.'}")

    def test_fail_add_work_no_abstract(self):
        # Get unittest user id
        user_list = vdc_user.get_users(name='unittest_user')
        user_id = user_list[0]['id']
        # Get unittest project id
        project_list = vdc_project.get_projects(title='unittest_project')
        project_id = project_list[0]['id']

        work_info = {
            'title': 'unittest_work',
            # 'abstract': 'unittest_abstract',
            'genre': 'DataSet',
            'visibility': 'open',
            'project': project_id,
            'created_by': user_id
        }
        try:
            new_work = vdc_work.add_work(work_info, auth_token='t3st')
            self.assertEqual(new_work, 'You are not here')
        except Exception as e:
            self.assertEqual(
                str(e),
                "Error adding work: 400 - {'message': 'Abstract is required.'}")
    
    def test_fail_add_work_no_genre(self):
        # Get unittest user id
        user_list = vdc_user.get_users(name='unittest_user')
        user_id = user_list[0]['id']
        # Get unittest project id
        project_list = vdc_project.get_projects(title='unittest_project')
        project_id = project_list[0]['id']

        work_info = {
            'title': 'unittest_work',
            'abstract': 'unittest_abstract',
            # 'genre': 'DataSet',
            'visibility': 'open',
            'project': project_id,
            'created_by': user_id
        }
        try:
            new_work = vdc_work.add_work(work_info, auth_token='t3st')
            self.assertEqual(new_work, 'You are not here')
        except Exception as e:
            self.assertEqual(
                str(e),
                "Error adding work: 400 - {'message': 'Genre is required.'}")

    def test_fail_add_work_no_visibility(self):
        # Get unittest user id
        user_list = vdc_user.get_users(name='unittest_user')
        user_id = user_list[0]['id']
        # Get unittest project id
        project_list = vdc_project.get_projects(title='unittest_project')
        project_id = project_list[0]['id']

        work_info = {
            'title': 'unittest_work',
            'abstract': 'unittest_abstract',
            'genre': 'DataSet',
            # 'visibility': 'open',
            'project': project_id,
            'created_by': user_id
        }
        try:
            new_work = vdc_work.add_work(work_info, auth_token='t3st')
            self.assertEqual(new_work, 'You are not here')
        except Exception as e:
            self.assertEqual(
                str(e),
                "Error adding work: 400 - {'message': 'Visibility is required.'}")
    
    def test_fail_add_work_no_project(self):
        # Get unittest user id
        user_list = vdc_user.get_users(name='unittest_user')
        user_id = user_list[0]['id']
        # Get unittest project id
        project_list = vdc_project.get_projects(title='unittest_project')
        project_id = project_list[0]['id']

        work_info = {
            'title': 'unittest_work',
            'abstract': 'unittest_abstract',
            'genre': 'DataSet',
            'visibility': 'open',
            # 'project': project_id,
            'created_by': user_id
        }
        try:
            new_work = vdc_work.add_work(work_info, auth_token='t3st')
            self.assertEqual(new_work, 'You are not here')
        except Exception as e:
            self.assertEqual(
                str(e),
                "Error adding work: 400 - {'message': 'Project is required.'}")
    
    def test_fail_add_work_no_created_by(self):
        # Get unittest user id
        user_list = vdc_user.get_users(name='unittest_user')
        user_id = user_list[0]['id']
        # Get unittest project id
        project_list = vdc_project.get_projects(title='unittest_project')
        project_id = project_list[0]['id']

        work_info = {
            'title': 'unittest_work',
            'abstract': 'unittest_abstract',
            'genre': 'DataSet',
            'visibility': 'open',
            'project': project_id,
            # 'created_by': user_id
        }
        try:
            new_work = vdc_work.add_work(work_info, auth_token='t3st')
            self.assertEqual(new_work, 'You are not here')
        except Exception as e:
            self.assertEqual(
                str(e),
                "Error adding work: 400 - {'message': 'created_by is required.'}")

    def tearDown(self):
        work_util.delete_unittest_works()
        project_util.delete_unittest_project()
        user_util.delete_unittest_users()
